@@ -2,8 +2,9 @@ package Catalyst::Plugin::ConfigLoader::Environment;
 
 use warnings;
 use strict;
-use JSON::Any;
-use MRO::Compat;
+use Catalyst::Utils;
+use NEXT;
+
 =head1 NAME
 
 Catalyst::Plugin::ConfigLoader::Environment - Configure your
@@ -11,11 +12,11 @@ application with environment variables.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.01
 
 =cut
 
-our $VERSION = '0.06_01';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -85,31 +86,18 @@ Let's translate a YAML config file:
       EVAL_PERL: 1
     Model::Bar:
       root: "/etc"
-    Model::DBIC:
-      connect_info: [ "dbi:Pg:dbname=foo", "username", "password" ]
 
 into environment variables that would setup the same configuration:
 
     MYAPP_name=MyApp
     MYAPP_title=This is My App!
-    MYAPP_View__Foo_EXTENSION=tt
-    MYAPP_View__Foo_EVAL_PERL=1
-    MYAPP_Model__Bar_root=/etc
-    MYAPP_Model__DBIC_connect_info=["dbi:Pg:dbname=foo", "username", "password"]
+    MYAPP_View::Foo_EXTENSION=tt
+    MYAPP_View::Foo_EVAL_PERL=1
+    MYAPP_Model::Bar_root=/etc
 
-Double colons are converted into double underscores.  For
-compatibility's sake, support for the 0.01-style use of
-bourne-incompatible variable names is retained.
-
-Values are JSON-decoded if they look like JSON arrays or objects
-(i.e. if they're enclosed in []s or {}s). Taking advantage of that, we
-can write the same example this way:
-
-    MYAPP_name=MyApp
-    MYAPP_title=This is My App!
-    MYAPP_View__Foo={"EXTENSION":"tt","EVAL_PERL":1}
-    MYAPP_Model__Bar={"root":"/etc"}
-    MYAPP_Model__DBIC={"connect_info":["dbi:Pg:dbname=foo", "username", "password"]}
+Note that C<bash> can't seem to deal with colons in the names of
+environment variables, so it's best to use something less braindead
+like C<envdir> from C<daemontools> to create them for you.
 
 =head1 FUNCTIONS
 
@@ -120,36 +108,21 @@ Overriding Catalyst' setup routine.
 =cut
 
 sub setup {
-    my $c    = shift;
+    my $c = shift;
     my $prefix = Catalyst::Utils::class2env($c);
     my %env;
     grep { /^${prefix}[_](.+)$/ && ($env{$1}=$ENV{$_})} keys %ENV;
 
     foreach my $var (keys %env) {
-        my $val = $env{$var};
-
-        # Decode JSON array/object 
-        if ( $val =~ m{^\[.*\]$|^\{.*\}$} ) {
-            $val = JSON::Any->jsonToObj($val);
-        }
-
-        # Special syntax Model__Foo is equivalent to Model::Foo
-        if($var =~ /(Model|View|Controller)(?:::|__)([^_]+)(?:_(.+))?$/) {
-            $var = "${1}::$2";
-
-            # Special syntax Model__Foo_bar (or Model::Foo_bar) will
-            # tweak just the 'bar' subparam for Model::Foo's
-            # config. We can accomplish this using a hash that
-            # specifies just 'bar' ($c->config will merge hashes).
-            if ( defined $3 ) {
-                $val = { $3 => $val };
-            }
-        }
-
-        $c->config( $var => $val );
+	if($var =~ /(Model|View|Controller)::([^_]+)_(.+)$/){
+	    $c->config->{"$1::$2"}->{$3} = $env{"$var"}; 
+	}
+	else {
+	    $c->config->{$var} = $env{$var};
+	}
     }
     
-    return $c->maybe::next::method(@_);
+    return $c->NEXT::setup(@_);
 }
 
 
@@ -157,14 +130,6 @@ sub setup {
 
 Jonathan Rockway, C<< <jrockway at cpan.org> >>
 
-=head1 CONTRIBUTORS
-
-mugwump
-
-Ryan D Johnson, C<< <ryan at innerfence.com> >>
-
-Devin J. Austin C<< <dhoss@cpan.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -191,6 +156,10 @@ L<mailto:catalyst@lists.rawmode.org>.
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Catalyst-Plugin-ConfigLoader-Environment>
 
+=item * My Trac site
+
+L<http://trac.jrock.us/cpan_modules/>
+
 =back
 
 =head1 COPYRIGHT & LICENSE
